Ory.Model.LoginFlowState
(ory_kratos v26.2.0)
The experimental state represents the state of a login flow. This field is EXPERIMENTAL and subject to change!
The experimental state represents the state of a login flow. This field is EXPERIMENTAL and subject to change!